#include <string>
#include <list>

#include "bluetooth.h"
#include <sys/types.h>
#include <sys/wait.h>

using namespace std;

BTManageAgent::BTManageAgent()
{
  

  //debug(DEBUG_APP, "BTManageAgent", "Starting hciconfig\n");

  int ret = system("/usr/sbin/hciconfig hci0 up");
  if (ret != 0) {
    perror("BTManageAgent hciconfig failed\n");
    exit(1);
  }
}

/*
 * If any device in n, is not in o, then put it in a and return true.
 * Otherwise return false.
 */
static bool check_devices_presence(list<string>& n,
				   list<string>& o,
				   list<string>& a)
{
  bool ret = false;
  for (list<string>::const_iterator i = n.begin();
       i != n.end(); ++i) {

    bool found = false;
    for (list<string>::const_iterator j = o.begin();
	 j != o.end(); ++j) {
      if ((*i) == (*j)) {
	found = true;
	break;
      }
    }

    if (!found) {
      ret = true;
      a.push_back((*i));
    }
  }
  return ret;
}

bool BTManageAgent::Inquire(std::list<std::string>& added,
			    std::list<std::string>& removed)
{
  int len     = 8;
  int max_rsp = 8;
  int num_rsp;
  int flags = IREQ_CACHE_FLUSH;

  int dev_id = hci_get_route(NULL);
  int sock = hci_open_dev(dev_id);

  if (dev_id < 0 || sock < 0){
    perror("hci_get_route  hci_open_dev ");
    return false;
  }
       
  inquiry_info *ii = NULL;
  num_rsp = hci_inquiry(dev_id, len, max_rsp, NULL, &ii, flags);

  if(num_rsp < 0) {
    perror("hci_inquiry ");
    close( sock );
    return false;
  }
    
  std::list<std::string> new_mac;
  for (int i=0; i<num_rsp; i++){
    char addr[19] = { 0 } ;
    ba2str(&(ii+i)->bdaddr, addr);
    char raddr[19] = { 0 } ;
    raddr[0] = addr[0];
    raddr[1] = addr[1];
    raddr[2] = '-';
    raddr[3] = addr[3];
    raddr[4] = addr[4];
    raddr[5] = '-';
    raddr[6] = addr[6];
    raddr[7] = addr[7];
    raddr[8] = '-';
    raddr[9] = addr[9];
    raddr[10] = addr[10];
    raddr[11] = '-';
    raddr[12] = addr[12];
    raddr[13] = addr[13];
    raddr[14] = '-';
    raddr[15] = addr[15];
    raddr[16] = addr[16];
    raddr[17] = addr[17];
     
    new_mac.push_back(std::string(raddr));
  }
  
  bool ret = false;
  /* if any device in new_mac is not in mac, put it in added */
  if (check_devices_presence(new_mac, mac, added)) {
    ret = true;
  }

  /* if any device in mac is not in new_mac, put it in removed. */
  if (check_devices_presence(mac, new_mac, removed)) {
    ret = true;
  }

  mac = new_mac;

  close( sock );
  return ret;
}

BTManageAgent::~BTManageAgent()
{
}


