# Columbia SIP makefile fragment for sipua
# Copyright 1999-2000 by Columbia University; all rights reserved 

sipua_dir := sipua

SIPUA_MODULES := docs

# Include the description for each sub-module
include $(patsubst %,$(topsrcdir)/$(sipua_dir)/%/module.mk,$(SIPUA_MODULES))


SIPUA_BIN := \
  $(sipua_dir)/sipua

SIPUA_SRC := \
  $(sipua_dir)/main.cpp \
  $(sipua_dir)/radio.cpp \
  $(sipua_dir)/bluetooth.cpp  

ifeq ($(USE_GSOAP), yes)
SIPUA_SRC += \
  $(sipconf_dir)/soapC.cpp \
  $(sipconf_dir)/soapClient.cpp \
  $(sipua_dir)/floorcontrol.cpp
endif

SIPUA_HEADERS := \
  $(sipua_dir)/radio.h \
  $(sipua_dir)/bluetooth.h \
  $(sipua_dir)/rtp.h \
  $(sipua_dir)/pcmu_l.h \
  $(sipua_dir)/types.h

ifeq ($(USE_GSOAP), yes)
SIPUA_HEADERS += \
  $(sipconf_dir)/fcdefs.h \
  $(sipua_dir)/floorcontrol.h
endif

SIPUA_MISC := \
  $(sipua_dir)/module.mk \
  $(sipua_dir)/sipua.dsp

SIPUA_MISCDIST := \
  $(sipua_dir)/README \
  $(sipua_dir)/sipua.license


SIPUA_NEEDED_LIBRARIES_LIST := \
	$(sipua_dir)/sipua-needed-shared-libraries

SIPUA_NEEDED_LIBRARIES_SOURCES := \
	$(sipua_dir)/sipua-needed-shared-libraries-sources

SIPUA_OBJ := \
	$(patsubst %.cpp,%.o,$(filter %.cpp,$(SIPUA_SRC)))

SIPUA_DEP := \
        $(SIPUA_OBJ:.o=.d)

SIPUA_MISCCLEAN := \
	$(SIPUA_NEEDED_LIBRARIES_LIST)

# Include directories required locally.
$(sipua_dir)-CFLAGS := $(LIBSIPAPI_INC) $(DBAPI_INC) $(LIBSIP_INC) \
                       $(LIBRTPPLUS_INC) $(LIBCINE_INC) $(SIPCONF_INC)

SIPUA_LIBS := $(LIBSIPAPI_LIB) $(LIBSIP_LIB) \
	$(DBAPI_LIB) $(LIBRTPPLUS_LIB) $(LIBCINE_LIB) \
	$(LIBRESPARSE_LIB) $(LIBDICT_LIB)  \
	$(READLINELIBS) $(GSOAPLIBS) \
	$(LDAPLIBS) $(DBAPI_LIB) \
        $(MYSQLLIBS) $(ZLIBLIBS) $(RESOLVLIBS) \
	$(TLSLIBS) $(NISLIBS) $(SOCKLIBS) $(MATHLIBS) $(DMALLOCCXXLIBS)
SIPUA_DEPENDENCIES := $(LIBSIPAPI) $(LIBSIP) $(LIBRTPPLUS) \
                      $(LIBCINE) $(LIBRESPARSE) \
                      $(LIBDICT) $(DBAPI)
SIPUA_REQS :=


$(SIPUA_NEEDED_LIBRARIES_SOURCES): $(sipua_dir)/sipua
	@echo "Building list of non-system shared libraries..."
	rm -f $(SIPUA_NEEDED_LIBRARIES_SOURCES)
	$(LDD) $(sipua_dir)/sipua | \
		sed -n -e '/not found/ s/^/XXX SET LD_LIBRARY_PATH: /p;' \
			-e '/=>/ s|^.* \([^ ]*/[^ ]*\).*$$|\1|p' | \
			egrep -v '^(/usr)?/lib/' \
			> $(SIPUA_NEEDED_LIBRARIES_SOURCES); \
			true
	if grep XXX $(SIPUA_NEEDED_LIBRARIES_SOURCES) > /dev/null; \
	then \
		echo "Missing shared library; can't continue"; \
		cat $(SIPUA_NEEDED_LIBRARIES_SOURCES); \
		rm -f $(SIPUA_NEEDED_LIBRARIES_SOURCES); \
		exit 1; \
	fi

$(SIPUA_NEEDED_LIBRARIES_LIST): $(SIPUA_NEEDED_LIBRARIES_SOURCES)
	@echo "Building local names of non-system shared libraries..."
	rm -f $(SIPUA_NEEDED_LIBRARIES_LIST)
	@sipua_needed_libraries=`cat $(SIPUA_NEEDED_LIBRARIES_SOURCES)`; \
	for library in $$sipua_needed_libraries; \
	do\
		echo $(sipua_dir)/`basename $$library`; \
	done > $(SIPUA_NEEDED_LIBRARIES_LIST)

# Do not add this --- all: $(SIPUA)
all: sipua
.PHONY: sipua
sipua: $(SIPUA_REQS) $(SIPUA_DEP) $(SIPUA_BIN)

# SIPUA uses libsipapi == LIBSIPAPI

$(sipua_dir)/sipua: $(SIPUA_OBJ) $(SIPUA_DEPENDENCIES)
	@echo "creating application $@..."
	$(CXX) -g -O2 -o $@ -w $(SIPUA_INCS) $(SIPUA_OBJ) \
	$(LDFLAGS) $(SIPUA_LIBS) $(LIBS)

BIN	  += $(SIPUA_BIN)
SRC	  += $(SIPUA_SRC)
MISC      += $(SIPUA_MISC)
MISCDIST  += $(SIPUA_MISCDIST)
MISCCLEAN += $(SIPUA_OTHER_MISCCLEAN)

SIPUA_DIST := $(SIPUA_SRC) $(SIPUA_HEADERS) $(SIPUA_MISC) $(SIPUA_MISCDIST)

SIPUA_BINDIST := $(SIPUA_MISCDIST) $(SIPUA_BIN)

SIPUA_MISC_DLLS := 

SIPUA_BIN_WIN32 := \
  $(sipua_dir)/Debug/sipua.exe \
  $(sipua_dir)/Release/sipua.exe

SIPUA_BINDIST_WIN32 := $(SIPUA_BIN_WIN32) $(SIPUA_MISCDIST) \
		      $(SIPUA_MISC_DLLS)

.PHONY: sipua-dist sipua-bindist sipua-bindist-win32 copy-sipua-shared-libraries

copy-sipua-shared-libraries: $(SIPUA_NEEDED_LIBRARIES_SOURCES)
	@echo "Copying non-system shared libraries..."
	@sipua_needed_libraries=`cat $(SIPUA_NEEDED_LIBRARIES_SOURCES)`; \
	if test "x$$sipua_needed_libraries" != "x"; \
	then\
		echo cp -f $$sipua_needed_libraries $(sipua_dir); \
		cp -f $$sipua_needed_libraries $(sipua_dir); \
	fi


SIPUA_DIST_NAME := sipua-$(VERSION)

SIPUA_DIST_FILES := \
	$(TOP_DIST) \
	$(LIBCINE_DIST) $(LIBSIP_DIST) $(LIBRESPARSE_DIST) \
	$(LIBDICT_DIST) \
	$(DBAPI_DIST) \
	$(WIN32_DIST) \
	$(LIBSIPAPI_DIST) \
	$(SIPUA_DIST) \
	$(SIPUA_DOCS_DIST) \
	$(DOC_DIST) \
	$(EXTRA_DIST_FILES)

sipua-dist: win32-dist
	$(MKDIST) $(topsrcdir) $(SIPUA_DIST_NAME) $(SIPUA_DIST_FILES)

SIPUA_BINDIST_NAME := sipua-$(VERSION)-$(SYSNAME)

SIPUA_BINDIST_FILES := \
		$(TOP_BINDIST) \
		$(LIBCINE_BINDIST) \
		$(LIBDICT_BINDIST) \
		\
		$(SIPUA_BINDIST) \
		$(SIPUA_DOCS_BINDIST) \
		$(DOC_BINDIST) \
		`cat $(SIPUA_NEEDED_LIBRARIES_LIST)` \
		$(EXTRA_BINDIST_FILES)

sipua-bindist:: $(SIPUA)  copy-sipua-shared-libraries \
			$(SIPUA_NEEDED_LIBRARIES_LIST)
	$(MKDIST) $(topsrcdir) $(SIPUA_BINDIST_NAME) $(SIPUA_BINDIST_FILES)


SIPUA_BINDIST_WIN32 := $(SIPUA_MISCDIST) \
		$(sipua_dir)/Debug/sipua.exe \
                $(sipua_dir)/Release/sipua.exe


SIPUA_BINDIST_WIN32_NAME := sipua-$(VERSION)-Win32

SIPUA_BINDIST_WIN32_FILES := \
		$(TOP_BINDIST) \
		$(LIBCINE_BINDIST) \
		$(LIBDICT_BINDIST) \
		\
		$(SIPUA_BINDIST_WIN32) \
		$(SIPUA_DOCS_BINDIST) \
		$(DOC_BINDIST) \
		$(EXTRA_BINDIST_FILES)

sipua-bindist-win32::
	$(MKDIST_WIN32) $(topsrcdir) $(SIPUA_BINDIST_WIN32_NAME) \
	$(SIPUA_BINDIST_WIN32_FILES)

sipua-help: 
	@echo "SIPUA (Test User Agent) Make Targets"
	@echo " make sipua                Make sipua executable on Unix."
	@echo " make sipua-dist           Make sipua source distribution."
	@echo " make sipua-bindist        Make sipua binary distribution for Unix."
	@echo " make sipua-bindist-win32  Make sipua binary distribution for Win32."

help: sipua-help
